"use strict";
// Copyright 2021 Canva Inc. All Rights Reserved.
Object.defineProperty(exports, "__esModule", { value: true });
exports.CssFileProcessor = void 0;
const postCssDetective = require("detective-postcss");
const logger_1 = require("../logger");
const logger = logger_1.debug.extend('css');
const error = logger.extend('error');
class CssFileProcessor {
    async process(file, contents, missing, files, dependencyTree) {
        const importedFiles = new Set();
        try {
            const referencedFiles = new Set(postCssDetective(contents, { url: true }));
            referencedFiles.forEach((referencedFile) => {
                dependencyTree.resolveAndCollect(file, dependencyTree.transformReference(referencedFile, file), importedFiles, missing);
            });
        }
        catch (e) {
            // We have a broken CSS file.
            // That doesn't mean our graph is incorrect, as it would also be broken in the browser.
            error('Error in %s when trying to parse CSS: %s', file, e.message);
        }
        return Promise.resolve(importedFiles);
    }
    match(file) {
        return /\.css$/i.test(file);
    }
    supportedFileTypes() {
        return ['css'];
    }
}
exports.CssFileProcessor = CssFileProcessor;
