import { DependencyTree, FileToDeps, Path } from '../';
import { FileProcessor } from '../file_processor';
declare type Options = {
    reStart: RegExp;
    reContinuation: RegExp;
    fileTypes: string[];
};
/**
 * An abstract DirectiveProcessor class that implements language-agnostic generic logic of
 * directives' parsing. For more info see: tools/dependency-tree/docs/directive.md.
 */
declare abstract class DirectiveProcessor implements FileProcessor {
    private readonly options;
    static readonly ELEMENT_NAME = "dependency-tree";
    private static readonly allowedAttributes;
    private readonly reMultilineDirectiveDelimiter;
    private readonly reExt;
    private readonly reNext;
    private readonly xmlParserOptions;
    protected constructor(options: Options);
    /**
     * Checks if the passed argument is an object of Directive shape and content is valid and throws
     * an exception otherwise.
     * @param obj - arbitrary payload
     */
    private static assertDirective;
    /**
     * Returns position of where the next symbol could be located at in terms of line & column
     * numbers. For example:
     *
     *   const str = `some
     *   kind
     *   of content
     *   presented here`;
     *
     *   const [lineNumber, columnNumber ] = DirectiveProcessor.getNextSymbolPosition(str);
     *
     *   assert(lineNumber === 4);
     *   assert(columnNumber === 15);
     *
     * @param content is a string that is going right before the position we would
     *                need to know.
     */
    private static getNextSymbolPosition;
    /**
     * @inheritDoc
     */
    process(file: Path, contents: string, missing: FileToDeps, files: ReadonlyArray<Path>, dependencyTree: DependencyTree): Promise<Set<string>>;
    match(file: Path): boolean;
    supportedFileTypes(): string[];
    /**
     * Returns directives defined in the content.
     *
     * @param content A content to parse
     * @param filePath A file path, for error reports only
     */
    private getDirectives;
}
/**
 * TypeScript triple-slash directives processor. The behavior is similar to the built-in TypeScript
 * triple-slash directive processor
 * (https://www.typescriptlang.org/docs/handbook/triple-slash-directives.html) but definition is
 * allowed across the whole file. For more info see: tools/dependency-tree/docs/directive.md.
 */
export declare class TSDirectiveProcessor extends DirectiveProcessor {
    constructor();
}
export {};
