import { FileToDeps, Path } from '../';
import { TypeScriptFileProcessor } from './typescript';
export declare type Storybook = string;
export declare type Story = string;
export declare type StorybookExtractorFn = (gherkinAssertion: string) => [Storybook, Story] | void;
export declare class FeatureFileProcessor extends TypeScriptFileProcessor {
    private readonly extractorFn;
    private storybookDefinitions;
    private stepsDefinitions;
    constructor(rootDir: string, extractorFn: StorybookExtractorFn);
    private static isRegExpToken;
    private static isImportDeclaration;
    private static isStoriesOf;
    private static isStoriesImport;
    private static isStringLiteral;
    private static isCallExpression;
    private static walkStories;
    private static walkSteps;
    process(file: Path, contents: string, missing: FileToDeps, files: ReadonlyArray<Path>): Promise<Set<Path>>;
    match(file: Path): boolean;
    supportedFileTypes(): string[];
    /**
     * This is only meant to be called once per execution of the dependency graph calculation.
     * The return value is a promise in order to facilitate potential asynchronicity to improve
     * performance later.
     * The passed files array is expected to be stable and never-changing.
     */
    private getStorybookDefinitions;
    /**
     * Extracts regular expressions matching gherkin step definitions from a given array of steps
     * files
     */
    private getStepsDefinitionRegExps;
    /**
     * Extracts all the steps.
     *
     * @param gherkinFile path to gherkin file
     * @return an array of steps
     */
    private getSteps;
    /**
     * Extracts references to Storybooks & stories from a given gherkin steps.
     *
     * @return  a map with a storybook name as the key and a value with a set of stories that are
     *          referenced by the gherkin file passed
     */
    private getReferencedStorybookMapping;
}
