"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JavascriptFileProcessor = exports.extractJsImports = void 0;
const path = require("path");
const acorn = require("acorn");
const esquery = require("esquery");
function extractJsImports(content) {
    const imports = new Set();
    const node = acorn.parse(content, {
        sourceType: 'module',
        allowHashBang: true,
        ecmaVersion: 'latest',
    });
    const importNodes = esquery(node, 'ImportDeclaration');
    importNodes.forEach((node) => {
        if (node.type === 'ImportDeclaration' &&
            node.source.type === 'Literal' &&
            typeof node.source.value === 'string') {
            imports.add(node.source.value);
        }
    });
    const requireNodes = esquery(node, 'CallExpression[callee.name="require"]');
    requireNodes.forEach((node) => {
        if (node.type === 'CallExpression' &&
            node.arguments.length === 1 &&
            node.arguments[0].type === 'Literal' &&
            typeof node.arguments[0].value === 'string') {
            imports.add(node.arguments[0].value);
        }
    });
    return imports;
}
exports.extractJsImports = extractJsImports;
class JavascriptFileProcessor {
    match(file) {
        const ext = path.extname(file);
        return ext === '.js' || ext === '.cjs' || ext === '.mjs';
    }
    supportedFileTypes() {
        return ['js', 'cjs', 'mjs'];
    }
    /**
     * @inheritDoc
     */
    process(file, contents, missing, files, dependencyTree) {
        const importedFiles = new Set();
        const referencedFiles = new Set(extractJsImports(contents));
        referencedFiles.forEach((referencedFile) => {
            dependencyTree.resolveAndCollect(file, dependencyTree.transformReference(referencedFile, file), importedFiles, missing);
        });
        return Promise.resolve(importedFiles);
    }
}
exports.JavascriptFileProcessor = JavascriptFileProcessor;
